@@ -4,8 +4,7 @@ use strict;
 use vars qw(@ISA $VERSION);
 require File::Spec::Unix;
 
-$VERSION = '3.58_01';
-$VERSION =~ tr/_//d;
+$VERSION = '1.4';
 
 @ISA = qw(File::Spec::Unix);
 
@@ -54,7 +53,7 @@ done in MacPerl's environment and helps to distinguish a file path from a
 directory path.
 
 B<IMPORTANT NOTE:> Beginning with version 1.3 of this module, the resulting
-path is relative by default and I<not> absolute. This decision was made due
+path is relative by default and I<not> absolute. This descision was made due
 to portability reasons. Since C<File::Spec-E<gt>catdir()> returns relative paths
 on all other operating systems, it will now also follow this convention on Mac
 OS. Note that this may break some existing scripts.
@@ -156,16 +155,13 @@ their Unix counterparts:
  Unix:
     Unix->catdir("","")                 =  "/"
     Unix->catdir("",".")                =  "/"
-    Unix->catdir("","..")               =  "/"        # can't go
-                                                      # beyond root
+    Unix->catdir("","..")               =  "/"              # can't go beyond root
     Unix->catdir("",".","..","..","a")  =  "/a"
  Mac:
-    Mac->catdir("","")                  =  rootdir()  # (e.g. "HD:")
+    Mac->catdir("","")                  =  rootdir()         # (e.g. "HD:")
     Mac->catdir("",":")                 =  rootdir()
-    Mac->catdir("","::")                =  rootdir()  # can't go
-                                                      # beyond root
-    Mac->catdir("",":","::","::","a")   =  rootdir() . "a:"
-                                                    # (e.g. "HD:a:")
+    Mac->catdir("","::")                =  rootdir()         # can't go beyond root
+    Mac->catdir("",":","::","::","a")   =  rootdir() . "a:"  # (e.g. "HD:a:")
 
 However, this approach is limited to the first arguments following
 "root" (again, see C<Unix-E<gt>canonpath()> ). If there are more
@@ -276,7 +272,7 @@ by default, but can be forced to be absolute (but avoid this).
 
 B<IMPORTANT NOTE:> Beginning with version 1.3 of this module, the
 resulting path is relative by default and I<not> absolute. This
-decision was made due to portability reasons. Since
+descision was made due to portability reasons. Since
 C<File::Spec-E<gt>catfile()> returns relative paths on all other
 operating systems, it will now also follow this convention on Mac OS.
 Note that this may break some existing scripts.
@@ -374,10 +370,10 @@ directory on your startup volume.
 
 =cut
 
+my $tmpdir;
 sub tmpdir {
-    my $cached = $_[0]->_cached_tmpdir('TMPDIR');
-    return $cached if defined $cached;
-    $_[0]->_cache_tmpdir($_[0]->_tmpdir( $ENV{TMPDIR} ), 'TMPDIR');
+    return $tmpdir if defined $tmpdir;
+    $tmpdir = $_[0]->_tmpdir( $ENV{TMPDIR} );
 }
 
 =item updir
@@ -403,11 +399,10 @@ the filename '' is always considered to be absolute. Note that with version
 
 E.g.
 
-    File::Spec->file_name_is_absolute("a");         # false (relative)
-    File::Spec->file_name_is_absolute(":a:b:");     # false (relative)
-    File::Spec->file_name_is_absolute("MacintoshHD:");
-                                                    # true (absolute)
-    File::Spec->file_name_is_absolute("");          # true (absolute)
+    File::Spec->file_name_is_absolute("a");             # false (relative)
+    File::Spec->file_name_is_absolute(":a:b:");         # false (relative)
+    File::Spec->file_name_is_absolute("MacintoshHD:");  # true (absolute)
+    File::Spec->file_name_is_absolute("");              # true (absolute)
 
 
 =cut
@@ -444,8 +439,7 @@ sub path {
 =item splitpath
 
     ($volume,$directories,$file) = File::Spec->splitpath( $path );
-    ($volume,$directories,$file) = File::Spec->splitpath( $path,
-                                                          $no_file );
+    ($volume,$directories,$file) = File::Spec->splitpath( $path, $no_file );
 
 Splits a path into volume, directory, and filename portions.
 
@@ -536,7 +530,7 @@ sub splitdir {
 	my @result = ();
 	my ($head, $sep, $tail, $volume, $directories);
 
-	return @result if ( (!defined($path)) || ($path eq '') );
+	return ('') if ( (!defined($path)) || ($path eq '') );
 	return (':') if ($path eq ':');
 
 	( $volume, $sep, $directories ) = $path =~ m|^((?:[^:]+:)?)(:*)(.*)|s;
@@ -745,7 +739,7 @@ sub rel2abs {
 
 	# Split up paths
 
-	# ignore $path's volume
+	# igonore $path's volume
         my ( $path_dirs, $path_file ) = ($self->splitpath($path))[1,2] ;
 
         # ignore $base's file part
